package com.ruoyi.system.service.impl.projectV2;

import java.util.List;

import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.system.domain.projectV2.ZsyzDbd;
import com.ruoyi.system.mapper.projectV2.ZsyzDbdMapper;
import com.ruoyi.system.service.projectV2.IZsyzDbdService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

/**
 * 招商引资_督办单Service业务层处理
 * 
 * @author boman
 * @date 2023-02-25
 */
@Service
public class ZsyzDbdServiceImpl implements IZsyzDbdService
{
    @Autowired
    private ZsyzDbdMapper zsyzDbdMapper;

    /**
     * 查询招商引资_督办单
     * 
     * @param id 招商引资_督办单主键
     * @return 招商引资_督办单
     */
    @Override
    public ZsyzDbd selectZsyzDbdById(Long id)
    {
        return zsyzDbdMapper.selectZsyzDbdById(id);
    }

    /**
     * 查询招商引资_督办单列表
     * 
     * @param zsyzDbd 招商引资_督办单
     * @return 招商引资_督办单
     */
    @Override
    public List<ZsyzDbd> selectZsyzDbdList(ZsyzDbd zsyzDbd)
    {
        return zsyzDbdMapper.selectZsyzDbdList(zsyzDbd);
    }

    /**
     * 新增招商引资_督办单
     * 
     * @param zsyzDbd 招商引资_督办单
     * @return 结果
     */
    @Override
    public int insertZsyzDbd(ZsyzDbd zsyzDbd)
    {
        zsyzDbd.setCreateTime(DateUtils.getNowDate());
        return zsyzDbdMapper.insertZsyzDbd(zsyzDbd);
    }

    /**
     * 修改招商引资_督办单
     * 
     * @param zsyzDbd 招商引资_督办单
     * @return 结果
     */
    @Override
    public int updateZsyzDbd(ZsyzDbd zsyzDbd)
    {
        zsyzDbd.setUpdateTime(DateUtils.getNowDate());
        return zsyzDbdMapper.updateZsyzDbd(zsyzDbd);
    }

    /**
     * 批量删除招商引资_督办单
     * 
     * @param ids 需要删除的招商引资_督办单主键
     * @return 结果
     */
    @Override
    public int deleteZsyzDbdByIds(Long[] ids)
    {
        return zsyzDbdMapper.deleteZsyzDbdByIds(ids);
    }

    /**
     * 删除招商引资_督办单信息
     * 
     * @param id 招商引资_督办单主键
     * @return 结果
     */
    @Override
    public int deleteZsyzDbdById(Long id)
    {
        return zsyzDbdMapper.deleteZsyzDbdById(id);
    }

    @Override
    public AjaxResult number(ZsyzDbd zsyzDbd) {
        long num = zsyzDbdMapper.number(zsyzDbd);
        return AjaxResult.success("成功",num);
    }
}
