package com.ruoyi.web.controller.projectV2;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.system.domain.projectV2.ZsyzDbd;
import com.ruoyi.system.service.projectV2.IZsyzDbdService;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 招商引资_督办单Controller
 * 
 * @author boman
 * @date 2023-02-25
 */
@RestController
@RequestMapping("/projectV2/dbd")
public class ZsyzDbdController extends BaseController
{
    @Autowired
    private IZsyzDbdService zsyzDbdService;

    /**
     * 查询招商引资_督办单列表
     */
    @PreAuthorize("@ss.hasPermi('projectV2:dbd:list')")
    @GetMapping("/list")
    public TableDataInfo list(ZsyzDbd zsyzDbd)
    {
        startPage();
        List<ZsyzDbd> list = zsyzDbdService.selectZsyzDbdList(zsyzDbd);
        return getDataTable(list);
    }


    /**
     * 查询招商引资_督办单列表
     */
    @GetMapping("/number")
    public AjaxResult number(ZsyzDbd zsyzDbd)
    {
        return zsyzDbdService.number(zsyzDbd);
    }


    /**
     * 导出招商引资_督办单列表
     */
    @PreAuthorize("@ss.hasPermi('projectV2:dbd:export')")
    @Log(title = "招商引资_督办单", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, ZsyzDbd zsyzDbd)
    {
        List<ZsyzDbd> list = zsyzDbdService.selectZsyzDbdList(zsyzDbd);
        ExcelUtil<ZsyzDbd> util = new ExcelUtil<ZsyzDbd>(ZsyzDbd.class);
        util.exportExcel(response, list, "招商引资_督办单数据");
    }

    /**
     * 获取招商引资_督办单详细信息
     */
    @PreAuthorize("@ss.hasPermi('projectV2:dbd:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(zsyzDbdService.selectZsyzDbdById(id));
    }

    /**
     * 新增招商引资_督办单
     */
    @PreAuthorize("@ss.hasPermi('projectV2:dbd:add')")
    @Log(title = "招商引资_督办单", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody ZsyzDbd zsyzDbd)
    {
        return toAjax(zsyzDbdService.insertZsyzDbd(zsyzDbd));
    }

    /**
     * 修改招商引资_督办单
     */
    @PreAuthorize("@ss.hasPermi('projectV2:dbd:edit')")
    @Log(title = "招商引资_督办单", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody ZsyzDbd zsyzDbd)
    {
        return toAjax(zsyzDbdService.updateZsyzDbd(zsyzDbd));
    }

    /**
     * 删除招商引资_督办单
     */
    @PreAuthorize("@ss.hasPermi('projectV2:dbd:remove')")
    @Log(title = "招商引资_督办单", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(zsyzDbdService.deleteZsyzDbdByIds(ids));
    }
}
